@@ -19,6 +19,8 @@ import mock
 from google.cloud.storage.retry import DEFAULT_RETRY
 from google.cloud.storage.retry import DEFAULT_RETRY_IF_METAGENERATION_SPECIFIED
 
+GCCL_INVOCATION_TEST_CONST = "gccl-invocation-id/test-invocation-123"
+
 
 class Test__get_storage_host(unittest.TestCase):
     @staticmethod
@@ -176,7 +178,9 @@ class Test_PropertyMixin(unittest.TestCase):
         derived._changes = object()
         derived.client = client
 
-        derived.reload(if_etag_match=etag,)
+        derived.reload(
+            if_etag_match=etag,
+        )
 
         self.assertEqual(derived._properties, response)
         self.assertEqual(derived._changes, set())
@@ -453,7 +457,8 @@ class Test_PropertyMixin(unittest.TestCase):
         timeout = 42
 
         derived.update(
-            if_metageneration_not_match=generation_number, timeout=timeout,
+            if_metageneration_not_match=generation_number,
+            timeout=timeout,
         )
 
         self.assertEqual(derived._properties, {"foo": "Foo"})
